============
Plot Options
============

Plot options commands are used to control the appearance of plots in the Visualization module. Plots can be undeformed, deformed, contour, symbol, or material orientation.

Object features
---------------

BasicOptions
~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.BasicOptions.BasicOptions
    :members:

    .. autoclasstoc::

CouplingConstraint
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.CouplingConstraint.CouplingConstraint
    :members:

    .. autoclasstoc::

DetailPlotOptions
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.DetailPlotOptions.DetailPlotOptions
    :members:

    .. autoclasstoc::

DGCommonOptions
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.DGCommonOptions.DGCommonOptions
    :members:

    .. autoclasstoc::

DGContourOptions
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.DGContourOptions.DGContourOptions
    :members:

    .. autoclasstoc::

DGDisplayBodyOptions
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.DGDisplayBodyOptions.DGDisplayBodyOptions
    :members:

    .. autoclasstoc::

DGOrientationOptions
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.DGOrientationOptions.DGOrientationOptions
    :members:

    .. autoclasstoc::

DGSuperimposeOptions
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.DGSuperimposeOptions.DGSuperimposeOptions
    :members:

    .. autoclasstoc::

DGSymbolOptions
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.DGSymbolOptions.DGSymbolOptions
    :members:

    .. autoclasstoc::

DisplayOptions
~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.DisplayOptions.DisplayOptions
    :members:

    .. autoclasstoc::

FreeBodyOptions
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.FreeBodyOptions.FreeBodyOptions
    :members:

    .. autoclasstoc::

HistoryVariable
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.HistoryVariable.HistoryVariable
    :members:

    .. autoclasstoc::

MdbData
~~~~~~~

.. autoclass:: abaqus.PlotOptions.MdbData.MdbData
    :members:

    .. autoclasstoc::

MdbDataFrame
~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.MdbDataFrame.MdbDataFrame
    :members:

    .. autoclasstoc::

MdbDataFrameArray
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.MdbDataFrameArray.MdbDataFrameArray
    :members:

    .. autoclasstoc::

MdbDataInstance
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.MdbDataInstance.MdbDataInstance
    :members:

    .. autoclasstoc::

MdbDataStep
~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.MdbDataStep.MdbDataStep
    :members:

    .. autoclasstoc::

MpcConstraint
~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.MpcConstraint.MpcConstraint
    :members:

    .. autoclasstoc::

OdbAnalysisError
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbAnalysisError.OdbAnalysisError
    :members:

    .. autoclasstoc::

OdbAnalysisWarning
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbAnalysisWarning.OdbAnalysisWarning
    :members:

    .. autoclasstoc::

OdbAuxiliaryData
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbAuxiliaryData.OdbAuxiliaryData
    :members:

    .. autoclasstoc::

OdbContactDiagnostics
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbContactDiagnostics.OdbContactDiagnostics
    :members:

    .. autoclasstoc::

OdbData
~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbData.OdbData
    :members:

    .. autoclasstoc::

OdbDataDatumCsys
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDataDatumCsys.OdbDataDatumCsys
    :members:

    .. autoclasstoc::

OdbDataElementSet
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDataElementSet.OdbDataElementSet
    :members:

    .. autoclasstoc::

OdbDataFrame
~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDataFrame.OdbDataFrame
    :members:

    .. autoclasstoc::

OdbDataFrameArray
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDataFrameArray.OdbDataFrameArray
    :members:

    .. autoclasstoc::

OdbDataInstance
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDataInstance.OdbDataInstance
    :members:

    .. autoclasstoc::

OdbDataMaterial
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDataMaterial.OdbDataMaterial
    :members:

    .. autoclasstoc::

OdbDataNodeSet
~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDataNodeSet.OdbDataNodeSet
    :members:

    .. autoclasstoc::

OdbDataSection
~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDataSection.OdbDataSection
    :members:

    .. autoclasstoc::

OdbDataStep
~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDataStep.OdbDataStep
    :members:

    .. autoclasstoc::

OdbDataSurfaceSet
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDataSurfaceSet.OdbDataSurfaceSet
    :members:

    .. autoclasstoc::

OdbDiagnosticAttempt
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDiagnosticAttempt.OdbDiagnosticAttempt
    :members:

    .. autoclasstoc::

OdbDiagnosticData
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDiagnosticData.OdbDiagnosticData
    :members:

    .. autoclasstoc::

OdbDiagnosticIncrement
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDiagnosticIncrement.OdbDiagnosticIncrement
    :members:

    .. autoclasstoc::

OdbDiagnosticStep
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDiagnosticStep.OdbDiagnosticStep
    :members:

    .. autoclasstoc::

OdbDisplayOptions
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbDisplayOptions.OdbDisplayOptions
    :members:

    .. autoclasstoc::

OdbJobTime
~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbJobTime.OdbJobTime
    :members:

    .. autoclasstoc::

OdbNumericalProblemSummary
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OdbNumericalProblemSummary.OdbNumericalProblemSummary
    :members:

    .. autoclasstoc::

OptionArg
~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.OptionArg.OptionArg
    :members:

    .. autoclasstoc::

PlyStackPlotOptions
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.PlyStackPlotOptions.PlyStackPlotOptions
    :members:

    .. autoclasstoc::

RigidBodyConstraint
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.RigidBodyConstraint.RigidBodyConstraint
    :members:

    .. autoclasstoc::

StreamOptions
~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.StreamOptions.StreamOptions
    :members:

    .. autoclasstoc::

TieConstraint
~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.TieConstraint.TieConstraint
    :members:

    .. autoclasstoc::

ViewCutOptions
~~~~~~~~~~~~~~

.. autoclass:: abaqus.PlotOptions.ViewCutOptions.ViewCutOptions
    :members:

    .. autoclasstoc::

